Skip to main contentModule logs
Source - Logs
- Displays logs for daemon(s)
- ReadyCheckType
- Describes the type of ready check being performed for display purposes.
- collect_startup_logs
- Collects startup log lines for a single daemon (does not print).
- colored_id_label
- Return a colorized
[namespace/id] label for display in progress jobs.
Uses brighter colors than dimmed_id and includes the square brackets. - create_ready_check_job
- Creates a progress job showing a spinner while waiting for a ready check.
- print_error_logs_block
- Prints error log lines in a styled block matching the startup logs format.
- stream_startup_logs
- Stream startup logs for a daemon to a progress job in real-time.
- tail_logs