create_ready_check_job

Function create_ready_check_job 

pub fn create_ready_check_job(
    daemon_id: &DaemonId,
    check_type: &ReadyCheckType,
) -> Arc<ProgressJob> 
Creates a progress job showing a spinner while waiting for a ready check.

Returns a Arc<ProgressJob> that the caller should update:

  • Set body to success message and status to Done when the daemon is ready
  • Set body to failure message and status to Failed when the daemon fails