handle_query

Function handle_query 

pub fn handle_query(query: &[u8], cfg: &ResolverConfig) -> Option<Vec<u8>>
Answer a DNS query.

Returns None when the datagram is not a query this responder should reply to at all (truncated below the header, or itself a response).