pub fn context_from_settings(s: &Settings, pac: bool) -> SetupContextExpand description
Build the context for the current machine and settings.
pub fn context_from_settings(s: &Settings, pac: bool) -> SetupContextBuild the context for the current machine and settings.