Module trust

Module trust 

CA certificate trust management for the reverse proxy.

Provides functions to:

  • Check if the pitchfork CA is trusted by the system (is_ca_trusted)
  • Install the CA into the system trust store (install_cert)
  • Remove the CA from the system trust store (uninstall_cert)
  • Auto-trust the CA during supervisor startup (auto_trust)

Enums

AutoTrustResult
Result of an auto-trust attempt.

Constants

TRUST_PROBE_TIMEOUT
The longest ca_trust_state takes before giving up on its own.

Functions

auto_trust
Attempt to automatically install the CA certificate into the system trust store during supervisor startup.
ca_trust_state
Whether the CA is trusted, or None when the trust store would not say.
install_cert
Install the CA certificate into the system trust store.
is_ca_trusted
Check if the pitchfork CA certificate is already trusted by the system.
uninstall_cert
Remove the pitchfork CA certificate from the system trust store.