Tera template rendering for pitchfork.toml configuration fields.
Allows run, env values, hooks.*, and the readiness fields (ready_cmd,
ready_http, ready_port, ready_output) to use Tera templates like
{{ daemons.redis.ports[0] }} to reference computed values from other daemons.
Templates are resolved level-by-level along the dependency order: each level can reference daemons from previous levels (which have already started and had their ports resolved).
Structs
- Daemon
Template State - Resolved state of a daemon available for template rendering.
- Template
Context - Context for rendering Tera templates in pitchfork.toml fields.
Enums
Functions
- render_
daemon_ templates - Render all template-enabled fields of a daemon config.
- render_
template - Render a Tera template string with the given context.