pub struct App {Show 37 fields
pub daemons: Vec<Daemon>,
pub disabled: Vec<DaemonId>,
pub selected: usize,
pub view: View,
pub prev_view: View,
pub log_content: Vec<String>,
pub log_daemon_id: Option<DaemonId>,
pub log_scroll: usize,
pub log_follow: bool,
pub message: Option<String>,
pub message_time: Option<Instant>,
pub process_stats: HashMap<u32, ProcessStats>,
pub stats_history: HashMap<DaemonId, StatsHistory>,
pub pending_action: Option<PendingAction>,
pub loading_text: Option<String>,
pub search_query: String,
pub search_active: bool,
pub sort_column: SortColumn,
pub sort_order: SortOrder,
pub log_search_query: String,
pub log_search_active: bool,
pub log_search_matches: Vec<usize>,
pub log_search_current: usize,
pub details_daemon_id: Option<DaemonId>,
pub logs_expanded: bool,
pub multi_select: HashSet<DaemonId>,
pub config_daemon_ids: HashSet<DaemonId>,
pub show_available: bool,
pub editor_state: Option<EditorState>,
pub file_selector: Option<ConfigFileSelector>,
pub network_listeners: Vec<Listener>,
pub network_search_query: String,
pub network_search_active: bool,
pub network_selected: usize,
pub network_scroll_offset: usize,
pub network_selected_pid: Option<u32>,
pub network_visible_rows: usize,
}Fields
daemons: Vec<Daemon>disabled: Vec<DaemonId>selected: usizeview: Viewprev_view: Viewlog_content: Vec<String>log_daemon_id: Option<DaemonId>log_scroll: usizelog_follow: boolmessage: Option<String>message_time: Option<Instant>process_stats: HashMap<u32, ProcessStats>stats_history: HashMap<DaemonId, StatsHistory>pending_action: Option<PendingAction>loading_text: Option<String>search_query: Stringsearch_active: boolsort_column: SortColumnsort_order: SortOrderlog_search_query: Stringlog_search_active: boollog_search_matches: Vec<usize>log_search_current: usizedetails_daemon_id: Option<DaemonId>logs_expanded: boolmulti_select: HashSet<DaemonId>config_daemon_ids: HashSet<DaemonId>show_available: booleditor_state: Option<EditorState>file_selector: Option<ConfigFileSelector>network_listeners: Vec<Listener>network_search_query: Stringnetwork_search_active: boolnetwork_selected: usizenetwork_scroll_offset: usizenetwork_selected_pid: Option<u32>network_visible_rows: usizeImplementations
Sourceimpl App
impl App
pub fn new() -> Self
pub fn confirm_action(&mut self, action: PendingAction)
pub fn cancel_confirm(&mut self)
pub fn take_pending_action(&mut self) -> Option<PendingAction>
pub fn start_loading(&mut self, text: impl Into<String>)
pub fn stop_loading(&mut self)
pub fn start_search(&mut self)
pub fn end_search(&mut self)
pub fn clear_search(&mut self)
pub fn search_push(&mut self, c: char)
pub fn search_pop(&mut self)
pub fn filtered_daemons(&self) -> Vec<&Daemon>
pub fn cycle_sort(&mut self)
pub fn toggle_sort_order(&mut self)
pub fn selected_daemon(&self) -> Option<&Daemon>
pub fn select_next(&mut self)
pub fn select_prev(&mut self)
pub fn toggle_log_follow(&mut self)
pub fn toggle_logs_expanded(&mut self)
pub fn toggle_select(&mut self)
pub fn select_all_visible(&mut self)
pub fn clear_selection(&mut self)
pub fn is_selected(&self, daemon_id: &DaemonId) -> bool
pub fn has_selection(&self) -> bool
pub fn selected_daemon_ids(&self) -> Vec<DaemonId>
pub fn set_message(&mut self, msg: impl Into<String>)
pub fn clear_stale_message(&mut self)
pub fn get_stats(&self, pid: u32) -> Option<&ProcessStats>
Sourcepub fn get_stats_history(&self, daemon_id: &DaemonId) -> Option<&StatsHistory>
pub fn get_stats_history(&self, daemon_id: &DaemonId) -> Option<&StatsHistory>
Get stats history for a daemon
pub async fn refresh(&mut self, client: &Arc<IpcClient>) -> Result<()>
Sourcepub async fn refresh_network(&mut self)
pub async fn refresh_network(&mut self)
Refresh network listeners data (for Network view)
Sourcepub fn filtered_network_listeners(&self) -> Vec<&Listener>
pub fn filtered_network_listeners(&self) -> Vec<&Listener>
Get filtered network listeners based on search query
Sourcepub fn toggle_network_search(&mut self)
pub fn toggle_network_search(&mut self)
Toggle network search active state
Sourcepub fn clear_network_search(&mut self)
pub fn clear_network_search(&mut self)
Clear network search
Sourcepub fn is_config_only(&self, daemon_id: &DaemonId) -> bool
pub fn is_config_only(&self, daemon_id: &DaemonId) -> bool
Check if a daemon is from config only (not currently active)
Sourcepub fn toggle_show_available(&mut self)
pub fn toggle_show_available(&mut self)
Toggle showing available daemons from config
pub fn scroll_logs_down(&mut self)
pub fn scroll_logs_up(&mut self)
Sourcepub fn scroll_logs_page_down(&mut self, visible_lines: usize)
pub fn scroll_logs_page_down(&mut self, visible_lines: usize)
Scroll down by half page (Ctrl+D)
Sourcepub fn scroll_logs_page_up(&mut self, visible_lines: usize)
pub fn scroll_logs_page_up(&mut self, visible_lines: usize)
Scroll up by half page (Ctrl+U)
pub fn start_log_search(&mut self)
pub fn end_log_search(&mut self)
pub fn clear_log_search(&mut self)
pub fn log_search_push(&mut self, c: char)
pub fn log_search_pop(&mut self)
pub fn log_search_next(&mut self)
pub fn log_search_prev(&mut self)
pub fn show_details(&mut self, daemon_id: &DaemonId)
pub fn hide_details(&mut self)
Sourcepub fn view_daemon_details(&mut self, daemon_id: &DaemonId)
pub fn view_daemon_details(&mut self, daemon_id: &DaemonId)
View daemon details (charts + logs)
pub fn show_help(&mut self)
pub fn back_to_dashboard(&mut self)
Sourcepub fn stats(&self) -> (usize, usize, usize, usize, usize)
pub fn stats(&self) -> (usize, usize, usize, usize, usize)
Returns (total, running, stopped, errored, available)
pub fn is_disabled(&self, daemon_id: &DaemonId) -> bool
Sourcepub fn get_config_files(&self) -> Vec<PathBuf>
pub fn get_config_files(&self) -> Vec<PathBuf>
Get list of available config file paths
Sourcepub fn open_file_selector(&mut self)
pub fn open_file_selector(&mut self)
Open file selector for creating a new daemon
Sourcepub fn open_editor_create(&mut self, config_path: PathBuf)
pub fn open_editor_create(&mut self, config_path: PathBuf)
Open editor for a new daemon with the selected config file
Sourcepub fn open_editor_edit(&mut self, daemon_id: &DaemonId)
pub fn open_editor_edit(&mut self, daemon_id: &DaemonId)
Open editor for an existing daemon
Sourcepub fn close_editor(&mut self)
pub fn close_editor(&mut self)
Close the editor and return to dashboard
Sourcepub fn save_editor_config(&mut self) -> Result<bool>
pub fn save_editor_config(&mut self) -> Result<bool>
Save the current editor state to config file. Returns Ok(true) if saved successfully, Ok(false) if validation/duplicate error (don’t close editor).