Module daemon_list

Module daemon_list 

Structs

DaemonListEntry
Represents a daemon entry that can be either tracked (from state file) or available (from config only)
NamespaceFilter
A set of namespaces to scope daemon listings to.

Functions

build_placeholder_daemon
Build a placeholder Daemon from config for daemons that exist in config but not state.
completed_oneshots
IDs of oneshot daemons that have already run to completion.
get_all_daemons
Get a unified list of all daemons from IPC client and config
get_all_daemons_direct
Get a unified list of all daemons from supervisor directly (for Web UI)
get_daemon_direct
Look up a single daemon by ID from state + config (for Web UI show handler).