Structs
- Daemon
List Entry - Represents a daemon entry that can be either tracked (from state file) or available (from config only)
Functions
- get_
all_ daemons - Get a unified list of all daemons from IPC client and config
- get_
all_ daemons_ direct - Get a unified list of all daemons from supervisor directly (for Web UI)
- get_
daemon_ direct - Look up a single daemon by ID from state + config (for Web UI show handler).