project_label

Function project_label 

pub fn project_label(primary: &Path) -> Option<String>
The project label for a primary checkout.

A project registered or configured with an explicit namespace uses that name; otherwise the directory name of the primary checkout is used.