pub fn plan_undo(ctx: &SetupContext) -> PlanExpand description
Build the plan for pitchfork proxy setup --undo.
Every step plan can take has a counterpart here; steps whose forward
version did nothing are simply absent.
pub fn plan_undo(ctx: &SetupContext) -> PlanBuild the plan for pitchfork proxy setup --undo.
Every step plan can take has a counterpart here; steps whose forward
version did nothing are simply absent.