pub struct Settings {
pub general: SettingsGeneral,
pub ipc: SettingsIpc,
pub supervisor: SettingsSupervisor,
pub tui: SettingsTui,
pub web: SettingsWeb,
}Fields
general: SettingsGeneralipc: SettingsIpcsupervisor: SettingsSupervisortui: SettingsTuiweb: SettingsWebImplementations
Sourceimpl Settings
impl Settings
Sourcepub fn load() -> Self
pub fn load() -> Self
Load settings from pitchfork.toml files, then overlay environment variables. Settings are loaded from all pitchfork.toml files in precedence order:
- System-level: /etc/pitchfork/config.toml
- User-level: ~/.config/pitchfork/config.toml
- Project-level: pitchfork.toml files from root to current directory Environment variables override all file-based settings.
Sourcepub fn load_from_env(&mut self)
pub fn load_from_env(&mut self)
Override settings from environment variables
Sourcepub fn apply_partial(&mut self, partial: &SettingsPartial)
pub fn apply_partial(&mut self, partial: &SettingsPartial)
Apply a partial settings overlay.
Only Some values in partial will override the corresponding fields in self.
Sourcepub fn parse_duration(s: &str) -> Option<Duration>
pub fn parse_duration(s: &str) -> Option<Duration>
Parse a duration string (humantime format) to Duration
Sourcepub fn general_autostop_delay(&self) -> Duration
pub fn general_autostop_delay(&self) -> Duration
Get general.autostop_delay as Duration
Sourcepub fn general_interval(&self) -> Duration
pub fn general_interval(&self) -> Duration
Get general.interval as Duration
Sourcepub fn ipc_connect_max_delay(&self) -> Duration
pub fn ipc_connect_max_delay(&self) -> Duration
Get ipc.connect_max_delay as Duration
Sourcepub fn ipc_connect_min_delay(&self) -> Duration
pub fn ipc_connect_min_delay(&self) -> Duration
Get ipc.connect_min_delay as Duration
Sourcepub fn ipc_rate_limit_window(&self) -> Duration
pub fn ipc_rate_limit_window(&self) -> Duration
Get ipc.rate_limit_window as Duration
Sourcepub fn ipc_request_timeout(&self) -> Duration
pub fn ipc_request_timeout(&self) -> Duration
Get ipc.request_timeout as Duration
Sourcepub fn supervisor_cron_check_interval(&self) -> Duration
pub fn supervisor_cron_check_interval(&self) -> Duration
Get supervisor.cron_check_interval as Duration
Sourcepub fn supervisor_file_watch_debounce(&self) -> Duration
pub fn supervisor_file_watch_debounce(&self) -> Duration
Get supervisor.file_watch_debounce as Duration
Sourcepub fn supervisor_http_client_timeout(&self) -> Duration
pub fn supervisor_http_client_timeout(&self) -> Duration
Get supervisor.http_client_timeout as Duration
Sourcepub fn supervisor_log_flush_interval(&self) -> Duration
pub fn supervisor_log_flush_interval(&self) -> Duration
Get supervisor.log_flush_interval as Duration
Sourcepub fn supervisor_ready_check_interval(&self) -> Duration
pub fn supervisor_ready_check_interval(&self) -> Duration
Get supervisor.ready_check_interval as Duration
Sourcepub fn supervisor_restart_delay(&self) -> Duration
pub fn supervisor_restart_delay(&self) -> Duration
Get supervisor.restart_delay as Duration
Sourcepub fn supervisor_stop_timeout(&self) -> Duration
pub fn supervisor_stop_timeout(&self) -> Duration
Get supervisor.stop_timeout as Duration
Sourcepub fn supervisor_watch_interval(&self) -> Duration
pub fn supervisor_watch_interval(&self) -> Duration
Get supervisor.watch_interval as Duration
Sourcepub fn tui_message_duration(&self) -> Duration
pub fn tui_message_duration(&self) -> Duration
Get tui.message_duration as Duration
Sourcepub fn tui_refresh_rate(&self) -> Duration
pub fn tui_refresh_rate(&self) -> Duration
Get tui.refresh_rate as Duration
Sourcepub fn tui_tick_rate(&self) -> Duration
pub fn tui_tick_rate(&self) -> Duration
Get tui.tick_rate as Duration
Sourcepub fn web_sse_poll_interval(&self) -> Duration
pub fn web_sse_poll_interval(&self) -> Duration
Get web.sse_poll_interval as Duration
Sourceimpl Settings
impl Settings
Sourcepub fn resolve_mise_bin(&self) -> Option<PathBuf>
pub fn resolve_mise_bin(&self) -> Option<PathBuf>
Resolve the mise binary path.
If general.mise_bin is explicitly set, returns that path.
Otherwise, searches well-known install locations:
~/.local/bin/mise~/.cargo/bin/mise/usr/local/bin/mise/opt/homebrew/bin/mise
Returns None if mise cannot be found.
Sourcepub fn default_port_bump_attempts(&self) -> u32
pub fn default_port_bump_attempts(&self) -> u32
Return supervisor.port_bump_attempts as u32, clamping out-of-range
values to the schema default (10) and zero to 1.
This is the single source of truth for the fallback so that call-sites
don’t each duplicate the hardcoded 10.